@@ -29,14 +29,17 @@ DBIx::Cookbook::DBH -- base class holding connection data and dbh() method
 
 DBIx::Cookbook::DBH is simply a derived class of L<DBIx::DBH>. Instances of 
 L<DBIx::Cookbook::DBH> supply database connection info in forms consumable
-by DBI(-based ORMs?, including
+by DBI(-based ORMs)?, including
 
 =over 4
 
-=item * DBI
-=item * DBIx::Class
-=item * DBIx::Skinny
-=item * Rose::DB::Object
+=item * L<DBI>
+
+=item * L<DBIx::Class>
+
+=item * L<DBIx::Skinny>
+
+=item * L<Rose::DB::Object>
 
 =back
 
